@@ -11,7 +11,7 @@ use Moo;
 use namespace::clean;
 
 # Version.
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 # Get XML.
 has xml => (
@@ -38,6 +38,8 @@ Map::Tube::Dnipropetrovsk - Interface to the Dnipropetrovsk Metro Map.
  use Map::Tube::Dnipropetrovsk;
  my $obj = Map::Tube::Dnipropetrovsk->new;
  my $routes_ar = $obj->get_all_routes($from, $to);
+ my $line = $obj->get_line_by_id($line_id);
+ my $line = $obj->get_line_by_name($line_name);
  my $lines_ar = $obj->get_lines;
  my $station = $obj->get_node_by_id($station_id);
  my $station = $obj->get_node_by_name($station_name);
@@ -66,6 +68,16 @@ For more information about Dnipropetrovsk Map, click L<here|https://en.wikipedia
  Get all routes from station to station.
  Returns reference to array with Map::Tube::Route objects.
 
+=item C<get_line_by_id($line_id)>
+
+ Get line object defined by id.
+ Returns Map::Tube::Line object.
+
+=item C<get_line_by_name($line_name)>
+
+ Get line object defined by name.
+ Returns Map::Tube::Line object.
+
 =item C<get_lines()>
 
  Get lines in metro map.
@@ -192,37 +204,21 @@ L<namespace::clean>.
 
 =head1 SEE ALSO
 
-L<Map::Tube>,
-L<Map::Tube::Graph>,
-L<Map::Tube::GraphViz>,
-L<Map::Tube::Plugin::Graph>,
-L<Map::Tube::Text::Table>,
-L<Task::Map::Tube>.
+=over
 
-L<Map::Tube::Barcelona>,
-L<Map::Tube::Berlin>,
-L<Map::Tube::Bucharest>,
-L<Map::Tube::Budapest>,
-L<Map::Tube::Delhi>,
-L<Map::Tube::Kazan>,
-L<Map::Tube::Kharkiv>,
-L<Map::Tube::Kiev>,
-L<Map::Tube::London>,
-L<Map::Tube::Minsk>,
-L<Map::Tube::Moscow>,
-L<Map::Tube::NYC>,
-L<Map::Tube::Nanjing>,
-L<Map::Tube::Novosibirsk>,
-L<Map::Tube::Prague>,
-L<Map::Tube::SaintPetersburg>,
-L<Map::Tube::Samara>,
-L<Map::Tube::Singapore>,
-L<Map::Tube::Sofia>,
-L<Map::Tube::Tbilisi>,
-L<Map::Tube::Tokyo>,
-L<Map::Tube::Vienna>,
-L<Map::Tube::Warsaw>,
-L<Map::Tube::Yekaterinburg>.
+=item L<Map::Tube>
+
+Core library as Role (Moo) to process map data.
+
+=item L<Task::Map::Tube>
+
+Install the Map::Tube modules.
+
+=item L<Task::Map::Tube::Metro>
+
+Install the Map::Tube concrete metro modules.
+
+=back
 
 =head1 REPOSITORY
 
@@ -242,6 +238,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.03
+0.04
 
 =cut
